Re: [PATCH] rev-list: preallocate object hash table in --all --objects
- From
Duy Nguyen <pclouds@gmail.com>
- Date
- Mar 29, 2013, 15:29 UTC
- Message-ID
- <CACsJy8AXUUz3=-pWeK-y0va-=d_-aCeNgH8rAtMZdq0PE+X97g@mail.gmail.com>
- In-Reply-To
- <20130329151208.GA22744@sigill.intra.peff.net>
On Fri, Mar 29, 2013 at 10:12 PM, Jeff King <peff@peff.net> wrote:
> This feels weirdly specific, and like we should just be tuning our hash > table growth better. You show a 3.2% speedup here. I was able to get a > 2.8% speedup just by doing this:
It also uses a lot more memory. 5.8m entries for ".. * 2" and 8.8m for "... * 3". Probably no big deal for modern machines..
> It might be worth trying to figure out what the optimium growth rate is > first, which would help this use case and others. With less fragile > code.
Agreed. Although I think it's getting out of my domain. I'm not even sure how many factors are involved.
-- Duy